package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberProjectRoleBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberProjectRoleDto;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberProjectRoleRequest;
import com.jz.dmp.modules.dao.sys.DmpMemberProjectRoleMapper;
import com.jz.dmp.modules.model.DmpMemberProjectRole;
import com.jz.dmp.modules.service.sys.DmpMemberProjectRoleService;

/**
 * 用户项目角色表服务的实现?
 * @author ybz
 *
 */
@Service("dmpMemberProjectRoleService")
public class DmpMemberProjectRoleServiceImpl extends BaseService implements DmpMemberProjectRoleService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpMemberProjectRoleServiceImpl.class);
	
	@Autowired
	private DmpMemberProjectRoleMapper dmpMemberProjectRoleMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#findList(com.ycxc.vmts.controller.bean.DmpMemberProjectRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpMemberProjectRoleDto> findList(DmpMemberProjectRoleRequest dmpMemberProjectRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpMemberProjectRoleDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpMemberProjectRoleRequest.getMemberProjectRoleId() != null) {
			param.put("memberProjectRoleId", dmpMemberProjectRoleRequest.getMemberProjectRoleId());
		}
		//用户ID
		if (dmpMemberProjectRoleRequest.getUserId() != null) {
			param.put("userId", dmpMemberProjectRoleRequest.getUserId());
		}
		//项目ID
		if (dmpMemberProjectRoleRequest.getProjectId() != null) {
			param.put("projectId", dmpMemberProjectRoleRequest.getProjectId());
		}
		//角色ID
		if (dmpMemberProjectRoleRequest.getRoleId() != null) {
			param.put("roleId", dmpMemberProjectRoleRequest.getRoleId());
		}
		
		PageHelper.startPage(dmpMemberProjectRoleRequest.getPageNum(), dmpMemberProjectRoleRequest.getPageSize());
		List<DmpMemberProjectRoleDto> list = dmpMemberProjectRoleMapper.findList(param);
		PageInfo<DmpMemberProjectRoleDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#add(com.ycxc.vmts.entity.DmpMemberProjectRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberProjectRole> add(DmpMemberProjectRole dmpMemberProjectRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberProjectRole> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpMemberProjectRoleMapper.insertSelective(dmpMemberProjectRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpMemberProjectRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#edit(com.ycxc.vmts.entity.DmpMemberProjectRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberProjectRole> edit(DmpMemberProjectRole dmpMemberProjectRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberProjectRole> baseBeanResponse = new BaseBeanResponse<>();
		
		dmpMemberProjectRoleMapper.updateByPrimaryKeySelective(dmpMemberProjectRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpMemberProjectRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#findById(com.ycxc.vmts.controller.bean.DmpMemberProjectRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpMemberProjectRoleDto> findById(DmpMemberProjectRoleRequest dmpMemberProjectRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpMemberProjectRoleDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpMemberProjectRoleDto dmpMemberProjectRoleDto = dmpMemberProjectRoleMapper.findById(dmpMemberProjectRoleRequest.getMemberProjectRoleId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpMemberProjectRoleDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#deleteById(com.ycxc.vmts.controller.bean.DmpMemberProjectRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpMemberProjectRoleRequest dmpMemberProjectRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpMemberProjectRoleMapper.deleteByPrimaryKey(dmpMemberProjectRoleRequest.getMemberProjectRoleId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberProjectRoleService#addBatch(com.ycxc.vmts.controller.bean.DmpMemberProjectRoleVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberProjectRoleBatch> addBatch(DmpMemberProjectRoleBatch dmpMemberProjectRoleBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberProjectRoleBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpMemberProjectRole> dmpMemberProjectRoles = dmpMemberProjectRoleBatch.getDmpMemberProjectRoles();
		
		if (CollectionUtils.isEmpty(dmpMemberProjectRoles)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpMemberProjectRoles = dmpMemberProjectRoles.stream().map(dmpMemberProjectRole -> {
			return dmpMemberProjectRole;
		}).collect(Collectors.toList());
		
		dmpMemberProjectRoleMapper.insertBatch(dmpMemberProjectRoles);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpMemberProjectRoleBatch);
		
		return baseBeanResponse;
	}
	
}
