package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberDto;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRequest;
import com.jz.dmp.modules.dao.sys.DmpMemberMapper;
import com.jz.dmp.modules.model.DmpMember;
import com.jz.dmp.modules.service.sys.DmpMemberService;

/**
 * 用户表服务的实现?
 * @author ybz
 *
 */
@Service("dmpMemberService")
public class DmpMemberServiceImpl extends BaseService implements DmpMemberService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpMemberServiceImpl.class);
	
	@Autowired
	private DmpMemberMapper dmpMemberMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#findList(com.ycxc.vmts.controller.bean.DmpMemberRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpMemberDto> findList(DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpMemberDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//用户ID
		if (dmpMemberRequest.getUserId() != null) {
			param.put("userId", dmpMemberRequest.getUserId());
		}
		//登录账号
		if (!StringUtils.isEmpty(dmpMemberRequest.getUserAccount())) {
			param.put("userAccount", dmpMemberRequest.getUserAccount());
		}
		//用户名称
		if (!StringUtils.isEmpty(dmpMemberRequest.getUserName())) {
			param.put("userName", dmpMemberRequest.getUserName());
		}
		//登录密码
		if (!StringUtils.isEmpty(dmpMemberRequest.getUserPassword())) {
			param.put("userPassword", dmpMemberRequest.getUserPassword());
		}
		//联系电话
		if (!StringUtils.isEmpty(dmpMemberRequest.getUserPhone())) {
			param.put("userPhone", dmpMemberRequest.getUserPhone());
		}
		//登录IP
		if (!StringUtils.isEmpty(dmpMemberRequest.getLoginIp())) {
			param.put("loginIp", dmpMemberRequest.getLoginIp());
		}
		//最近登录时间起
		if (dmpMemberRequest.getLoginTimeStart() != null) {
			param.put("loginTimeStart", dmpMemberRequest.getLoginTimeStart());
		}
		//最近登录时间止
		if (dmpMemberRequest.getLoginTimeEnd() != null) {
			param.put("loginTimeEnd", dmpMemberRequest.getLoginTimeEnd());
		}
		//是否登录锁定(0：否，1：是)
		if (!StringUtils.isEmpty(dmpMemberRequest.getLoginLocked())) {
			param.put("loginLocked", dmpMemberRequest.getLoginLocked());
		}
		//连续登录错误次数
		if (dmpMemberRequest.getLoginErrtimes() != null) {
			param.put("loginErrtimes", dmpMemberRequest.getLoginErrtimes());
		}
		//备注
		if (!StringUtils.isEmpty(dmpMemberRequest.getRemark())) {
			param.put("remark", dmpMemberRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpMemberRequest.getDataStatus())) {
			param.put("dataStatus", dmpMemberRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpMemberRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpMemberRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpMemberRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpMemberRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpMemberRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpMemberRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpMemberRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpMemberRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpMemberRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpMemberRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpMemberRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpMemberRequest.getUpdateTimeEnd());
		}
		
		PageHelper.startPage(dmpMemberRequest.getPageNum(), dmpMemberRequest.getPageSize());
		List<DmpMemberDto> list = dmpMemberMapper.findList(param);
		PageInfo<DmpMemberDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#add(com.ycxc.vmts.entity.DmpMember, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMember> add(DmpMember dmpMember, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<>();
		
		/*$*setUserIdCodeReplace*$*/
		//创建人
		dmpMember.setCreateUserId(getHttpRequestUserId(httpRequest));
		//创建时间
		dmpMember.setCreateTime(new Date());
		
		dmpMemberMapper.insertSelective(dmpMember);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpMember);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#edit(com.ycxc.vmts.entity.DmpMember, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMember> edit(DmpMember dmpMember, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<>();
		
		//修改人
		dmpMember.setUpdateUserId(getHttpRequestUserId(httpRequest));
		//修改时间
		dmpMember.setUpdateTime(new Date());
		
		dmpMemberMapper.updateByPrimaryKeySelective(dmpMember);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpMember);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#findById(com.ycxc.vmts.controller.bean.DmpMemberRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpMemberDto> findById(DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpMemberDto dmpMemberDto = dmpMemberMapper.findById(dmpMemberRequest.getUserId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpMemberDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#deleteById(com.ycxc.vmts.controller.bean.DmpMemberRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpMemberMapper.deleteByPrimaryKey(dmpMemberRequest.getUserId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpMemberService#addBatch(com.ycxc.vmts.controller.bean.DmpMemberVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpMemberBatch> addBatch(DmpMemberBatch dmpMemberBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpMemberBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpMember> dmpMembers = dmpMemberBatch.getDmpMembers();
		
		if (CollectionUtils.isEmpty(dmpMembers)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpMembers = dmpMembers.stream().map(dmpMember -> {
			/*$*setUserIdCodeReplace*$*/
			//创建人
			try {
				dmpMember.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			//创建时间
			dmpMember.setCreateTime(new Date());
			
			return dmpMember;
		}).collect(Collectors.toList());
		
		dmpMemberMapper.insertBatch(dmpMembers);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpMemberBatch);
		
		return baseBeanResponse;
	}


	/**
	 *通过用户名获取用户信息
	 */
	@Override
	public DmpMember findByUserName(String userName) throws Exception {
		DmpMember dmpMember = dmpMemberMapper.findByUserName(userName);
		return dmpMember;
	}
	
}
